.truncate {
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}

/* Some bootstrap styles */
[type="button"]:not(:disabled),
[type="reset"]:not(:disabled),
[type="submit"]:not(:disabled),
button:not(:disabled),
.btn:not(:disabled) {
  cursor: pointer;
}

button:disabled,
.btn:disabled {
  cursor: default;
}

.btn {
  display: inline-block;
  line-height: 1.5;
  text-align: center;
  text-decoration: none;
  vertical-align: middle;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
  background-color: transparent;
  border: 1px solid transparent;
  padding: 0.375rem 0.75rem;
  border-radius: 0.25rem;
}

.btn:focus {
  outline: none !important;
}

.btn.disabled {
  pointer-events: none;
  opacity: 0.65;
}

.btn-primary {
  color: #fff;
  background-color: #0d6efd;
  border-color: #0d6efd;
}

.btn-primary:hover:not(:disabled) {
  color: #fff;
  background-color: #0b5ed7;
  border-color: #0a58ca;
}

.btn-secondary {
  color: #fff;
  background-color: #6c757d;
  border-color: #6c757d;
}

.btn-secondary:hover {
  color: #fff;
  background-color: #5c636a;
  border-color: #565e64;
}

.btn-success {
  color: #fff;
  background-color: #28a745;
  border-color: #28a745;
}

.btn-success:hover {
  color: #fff;
  background-color: #218838;
  border-color: #1e7e34;
}

.btn-warning {
  color: #000;
  background-color: #ffc107;
  border-color: #ffc107;
}

.btn-warning:hover {
  color: #000;
  background-color: #ffca2c;
  border-color: #ffc720;
}

.btn-dark {
  color: #fff;
  background-color: #212529;
  border-color: #212529;
}

.btn-dark:hover {
  color: #fff;
  background-color: #1c1f23;
  border-color: #1a1e21;
}

.btn-light {
  color: #000;
  background-color: #f8f9fa;
  border-color: #f8f9fa;
}

.btn-light:hover {
  color: #000;
  background-color: #f9fafb;
  border-color: #f9fafb;
}

input:not([type="file"]),
select {
  --tw-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000),
    var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
  border-width: 1px;
  border-radius: 0.25rem;
  padding-top: 0.5rem /* 8px */;
  padding-bottom: 0.5rem /* 8px */;
  padding-left: 0.75rem /* 12px */;
  padding-right: 0.75rem /* 12px */;
  --tw-text-opacity: 1;
  color: rgba(55, 65, 81, var(--tw-text-opacity));
  line-height: 1.25;
}

select:focus {
  outline: none;
}

input[type="input"],
input[type="file"] {
  appearance: none;
  outline: none;
  border: none;
}

input:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

textarea {
  appearance: none;
  color: black;
  padding: 1rem;
}

textarea:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

select:after {
  position: absolute;
  content: "";
  top: 14px;
  right: 10px;
  width: 0;
  height: 0;
  border: 6px solid transparent;
  border-color: rgb(231, 33, 33) transparent transparent transparent;
}

input[type="checkbox"] {
  /* Double-sized Checkboxes */
  -ms-transform: scale(1.2); /* IE */
  -moz-transform: scale(1.2); /* FF */
  -webkit-transform: scale(1.2); /* Safari and Chrome */
  -o-transform: scale(1.2); /* Opera */
  transform: scale(1.2);
  margin-right: 0.4rem;
  cursor: pointer;
}

.normal-link {
  text-decoration: underline;
  color: rgba(147, 197, 253);
}

.normal-link:hover {
  color: rgba(96, 165, 250);
}

/* Accounts */
.account {
  width: 100%;
  margin-top: 4rem;
}

.T-account-header h2,
h3 {
  margin-bottom: 0rem;
  margin-top: 1rem;
  line-height: 0;
}

.T-account-header {
  display: flex;
  width: 100%;
  justify-content: space-between;
  padding-bottom: 0.8rem;
  border-bottom: 2px solid gray;
}

.T-account {
  display: flex;
  width: 100%;
  justify-content: space-between;
  min-height: 400px;
  padding-bottom: 2rem;
}

.T-account-DR,
.T-account-CR {
  width: 50%;
}

.T-account-CR {
  padding-left: 1.5rem;
  margin-right: -1.5rem;
}

.T-account-DR-header,
.T-account-CR-header {
  display: flex;
  width: 100%;
  margin-bottom: 3rem;
}

.T-account-DR-header div,
.T-account-CR-header div {
  flex: 1 1 0px;
}

.T-account-transaction-lines {
  display: flex;
  flex-direction: column;
}

.T-account-transaction-line {
  display: flex;
  width: 100%;
  margin-bottom: 1rem;
}

.T-account-transaction-line div {
  flex: 1 1 0px;
}

.col-amount {
  text-align: right;
  margin-right: 2rem;
}
